import React from 'react';
import styled from "styled-components";
import Loading from '../../util/Loading';
import Button from "../../util/Button";
import PlayerScoreTile from "./PlayerScoreTile";
import useGameInfo from '../../../hooks/useGameInfo';
import ClickToCopy from '../../util/ClickToCopy';
import { useGameId, dispatch } from '../../../domain/gameStore';
import { linkGame } from '../../../domain/apiMethods';
import GameCreationForm from '../../util/GameCreationForm';

const Container = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-between;
  align-items: center;
  height: 100%;
`

const ScoreBoard = styled.div`
  flex: 2;
  display: flex;
  flex-flow: row wrap;
  justify-content: space-evenly;
  align-items: flex-start;
  align-content: space-around;
  max-width: 80%;
  margin-top: 2em;
`

const LinkedGameContainer = styled.div`
  display: flex;
  justify-content: center;
  width: 100%;
  margin-top: 1em;
  margin-bottom: 10em;
`

const Label = styled.span`
  padding: 0.2em;
  margin-bottom: 0.5em;
`

const StyledButton = styled(Button)`
  margin-top: 0.5em;
`

const getUrl = gameId => {
  const u = new URL(window.location.href);
  u.searchParams.append("summary", gameId);
  return u.href;
}

export default () => {
  const gameId = useGameId();
  const { players, linkedGame }  = useGameInfo();

  if (!players) {
    return <Loading/>
  }

  return (
    <Container>
      <ScoreBoard>
        {
          players
            .filter(({ currentRound }) => currentRound === null)
            .sort((p1, p2) => p1.totalScore > p2.totalScore ? -1 : (p1.totalScore < p2.totalScore ? 1 : 0))
            .map((data) => <PlayerScoreTile key={data.name} {...data} />)
        }
      </ScoreBoard>
      <LinkedGameContainer>
        {
          linkedGame
            ? <StyledButton onClick={() => dispatch.goToLobby(linkedGame)}>
                Continue to Linked Game Lobby
              </StyledButton>
            : <GameCreationForm afterCreate={linkId => linkGame(gameId, linkId)}/>
        }
      </LinkedGameContainer>
      <Label><ClickToCopy text={getUrl(gameId)}>Click here to copy a link to this summary!</ClickToCopy></Label>
    </Container>
  );
}
